pm4py.algo.evaluation.precision package
=======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.evaluation.precision.dfg
   pm4py.algo.evaluation.precision.variants

Submodules
----------

pm4py.algo.evaluation.precision.algorithm module
------------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.precision.evaluator module
------------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.precision.parameters module
-------------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.parameters
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.precision.utils module
--------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation.precision
   :members:
   :undoc-members:
   :show-inheritance:
